##
##  lzip.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg  1.24.1
%define       V_dist  1.24.1

#   package information
Name:         lzip
Summary:      LZMA Compression Tool
URL:          http://www.nongnu.org/lzip/lzip.html
Vendor:       Antonio Diaz Diaz
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Compression
License:      GPL
Version:      %{V_opkg}
Release:      20240302

#   list of sources
Source0:      http://download.savannah.gnu.org/releases/lzip/lzip-%{V_dist}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Lzip is a lossless file compressor based on the LZMA
    (Lempel-Ziv-Markov chain-Algorithm) algorithm, designed by Igor
    Pavlov. The high compression of LZMA comes from combining two basic,
    well-proven compression ideas: sliding dictionaries (i.e. LZ77/78),
    and Markov models (i.e. the thing used by every compression
    algorithm that uses a range encoder or similar order-0 entropy coder
    as its last stage) with segregation of contexts according to what
    the bits are used for. Lzip has a user interface similar to the one
    of gzip(1) or bzip2(1).

%track
    prog lzip = {
        version   = %{V_dist}
        url       = http://download.savannah.gnu.org/releases/lzip/
        regex     = lzip-(\d+\.\d+(?:\.\d+)?)\.tar\.gz
    }

%prep
    %setup -q -n lzip-%{V_dist}

%build
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    ./configure \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
        --mandir=%{l_prefix}/man
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install install-man DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

